Applies min-max normalization to a numeric vector, optionally clamping values to [0, 1].
Usage
normalize_01(x, direction = c("higher_better", "lower_better"), clamp = TRUE)Applies min-max normalization to a numeric vector, optionally clamping values to [0, 1].
normalize_01(x, direction = c("higher_better", "lower_better"), clamp = TRUE)